@@ -1,9 +1,9 @@
 //////////////////////////////////////////////////////////////////////////
 //
 // pgAgent - PostgreSQL Tools
-// $Id: job.h 7533 2009-01-05 14:02:35Z dpage $
-// Copyright (C) 2002 - 2009, The pgAdmin Development Team
-// This software is released under the Artistic Licence
+//
+// Copyright (C) 2002 - 2014, The pgAdmin Development Team
+// This software is released under the PostgreSQL Licence
 //
 // job.h - agent job
 //
@@ -19,25 +19,31 @@
 class Job
 {
 public:
-    Job(DBconn *conn, const wxString &jid);
-    ~Job();
+	Job(DBconn *conn, const wxString &jid);
+	~Job();
 
-    int Execute();
-    bool Runnable() { return status == wxT("r"); }
+	int Execute();
+	bool Runnable()
+	{
+		return status == wxT("r");
+	}
 
 protected:
-    DBconn *threadConn;
-    wxString jobid, logid;
-    wxString status;
+	DBconn *threadConn;
+	wxString jobid, logid;
+	wxString status;
 };
 
 
 class JobThread : public wxThread
 {
 public:
-    JobThread(const wxString &jid);
-    ~JobThread();
-	bool Runnable() { return runnable; }
+	JobThread(const wxString &jid);
+	~JobThread();
+	bool Runnable()
+	{
+		return runnable;
+	}
 
 	virtual void *Entry();
 
